.. libadalina-analytics documentation master file, created by
   sphinx-quickstart on Thu Oct 26 10:00:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=============================
libadalina-analytics documentation
=============================

.. toctree::
   :maxdepth: 2
   :caption: Table of contents

   introduction
   instructions/index
   modules/index

